# Neighbour finders

```eval_rst
.. currentmodule:: baggianalysis.core

.. autosummary::
    :nosignatures:

    NeighbourFinder
    FixedNumberFinder
    CutoffFinder
    SANNFinder
    
.. autoclass:: NeighbourFinder
    
.. autoclass:: FixedNumberFinder

.. autoclass:: CutoffFinder
    
.. autoclass:: SANNFinder
```
